@@ -29,6 +29,9 @@ class Module(core.module.Module):
         super().__init__(config, theme, core.widget.Widget(self.get_progress_text))
         self.__active = False
 
+    def hidden(self):
+        return not self.__active
+
     def get_progress_text(self, widget):
         if self.update_progress_info(widget):
             width = util.format.asint(self.parameter("barwidth", 8))
@@ -53,7 +56,7 @@ class Module(core.module.Module):
             return self.parameter("placeholder", "n/a")
 
     def update_progress_info(self, widget):
-        """Update widget's informations about the copy"""
+        """Update widget's information about the copy"""
         if not self.__active:
             return
 
@@ -61,8 +64,8 @@ class Module(core.module.Module):
         #  1. pid
         #  2. command
         #  3. arguments
-        #  4. progress (xx.x formated)
-        #  5. quantity (.. unit / .. unit formated)
+        #  4. progress (xx.x formatted)
+        #  5. quantity (.. unit / .. unit formatted)
         #  6. speed
         #  7. time remaining
         extract_nospeed = re.compile(
@@ -77,7 +80,7 @@ class Module(core.module.Module):
             result = extract_wtspeed.match(raw)
 
             if not result:
-                # Abord speed measures
+                # Abort speed measures
                 raw = util.cli.execute("progress -q")
                 result = extract_nospeed.match(raw)
 
